CedarBackup3.actions.stage — cedar-backup3 3.10.0 documentation

# CedarBackup3.actions.stage

Implements the standard ‘stage’ action. :author: Kenneth J. Pronovici <pronovic@ieee.org>

## Module Contents

CedarBackup3.actions.stage.logger

CedarBackup3.actions.stage.executeStage(configPath, options, config)

  Executes the stage backup action.

  Note: The daily directory is derived once and then we stick with it, just in case a backup happens to span midnite.

  Note: As portions of the stage action is complete, we will write various indicator files so that it’s obvious what actions have been completed. Each peer gets a stage indicator in its collect directory, and then the master gets a stage indicator in its daily staging directory. The store process uses the master’s stage indicator to decide whether a directory is ready to be stored. Currently, nothing uses the indicator at each peer, and it exists for reference only.

  Parameters:

    - configPath (String representing a path on disk) – Path to configuration file on disk

    - options (Options object) – Program command-line options

    - config (Config object) – Program configuration

  Raises:

    - ValueError – Under many generic error conditions

    - IOError – If there are problems reading or writing files